@@ -1,6 +1,6 @@
 /*
  * CLISP: GDBM <http://www.gnu.org/software/gdbm/>
- * Copyright (C) 2003 by Sam Steingold
+ * Copyright (C) 2003-2004 by Sam Steingold
  */
 
 /* have to undefing UNICODE _here_ because clisp.h will #include <windows.h> */
@@ -17,20 +17,22 @@
 # define UNIX_CYGWIN32
 #endif
 
-#define WIN32_LEAN_AND_MEAN  /* avoid including junk */
-#if defined(UNIX_CYGWIN32) || defined(__MINGW32__)
+#if defined(_WIN32) || defined(UNIX_CYGWIN32)
+# define WIN32_LEAN_AND_MEAN  /* avoid including junk */
+# if defined(UNIX_CYGWIN32) || defined(__MINGW32__)
 /* `unused' is used in function declarations. */
-# undef unused
-# define ULONGLONG OS_ULONGLONG
-# define ULONG OS_ULONG
-# include <windows.h>
-# undef ULONG
-# undef ULONGLONG
-# define unused (void)
-#else
-# undef unused
-# include <windows.h>
-# define unused
+#  undef unused
+#  define ULONGLONG OS_ULONGLONG
+#  define ULONG OS_ULONG
+#  include <windows.h>
+#  undef ULONG
+#  undef ULONGLONG
+#  define unused (void)
+# else
+#  undef unused
+#  include <windows.h>
+#  define unused
+# endif
 #endif
 
 #include <string.h>             /* for memset() */
@@ -50,7 +52,7 @@ extern object nobject_out (FILE* stream, object obj);
 
 #include <db.h>
 
-DEFMODULE(bdb,"BDB");
+DEFMODULE(bdb,"BDB")
 
 DEFUN(BDB:DB-VERSION,)
 { /* Berkeley-DB version */
